
(require 'printf)
(require 'optics)
(require 'databases)
(require 'database-interpolate)

(defvar nk (open-database (or (getenv "NK_DATABASE_PATH") "nk.rwb") 'rwb-isam))
(defvar bk7 (interpolate-from-table (open-table nk 'bk7) 2))
(defvar ag (interpolate-from-table (open-table nk 'ag) 2))
(defvar au (interpolate-from-table (open-table nk 'au) 2))
(define (sputtered-ag w) (scatter-ir (ag w) .85 1))
(define ag-thicks '(1.0e-9 2.1e-9 3.2e-9 4.3e-9 5.2e-9 6.0e-9 7.0e-9 10e-9))
(define ag-descriptions
  '(light-yellow
    golden-yellow
    orange-yellow
    ruddy-orange
    crimson
    indigo
    uncolored
    thick))
(define ag-colors
  (map (lambda (d)
	 (print (CIEXYZ->color
		 (stack->XYZ 0 (optical-stack
				(layer sputtered-ag d)
				(substrate BK7)))))) ;1.5164
       ag-thicks))
(write-color-sampler.pdf 'ag
			 ag-colors
			 (map (lambda (x) (sprintf #f "%.2km" x)) ag-thicks)
			 ag-descriptions)
(newline)

;;(define (sputtered-au w) (scatter-ir (au w) .7 1))
(define au-thicks '(1.5e-9 2.0e-9 2.7e-9 3.2e-9 4.0e-9 10e-9 100e-9))
(define au-q      '(.2     .3     .4     .5     .6     .7      .7))
(define au-descriptions
  '(ruddy-purple
    indigo
    blue
    green
    yellow-green
    golden-yellow
    golden-yellow))
(define au-colors
  (map (lambda (d q)
	 (print (CIEXYZ->color
		 (stack->XYZ 0 (optical-stack
				(layer (lambda (w) (scatter-ir (au w) q 1)) d)
				(substrate BK7)))))) ;1.5164
       au-thicks
       au-q))
(write-color-sampler.pdf 'au
			 au-colors
			 (map (lambda (x) (sprintf #f "%.2km" x)) au-thicks)
			 au-descriptions)
(system "gv au-colors.pdf")
